@@ -14,9 +14,9 @@
 # above as well as the notices contained in other source files with your
 # own copyright notice.  Recommended free  licenses are  the GNU General
 # Public License, GNU Lesser General Public License, Expat License, or
-# Apache License 2.0.
+# Apache License.
 
-__all__ = ['Music']
+import sge
 
 
 class Music(object):
