@@ -14,14 +14,11 @@
 # above as well as the notices contained in other source files with your
 # own copyright notice.  Recommended free  licenses are  the GNU General
 # Public License, GNU Lesser General Public License, Expat License, or
-# Apache License 2.0.
+# Apache License.
 
 import sge
 
 
-__all__ = ['Sprite']
-
-
 class Sprite(object):
 
     """Class which holds information for images and animations.
@@ -407,6 +404,24 @@ class Sprite(object):
         """
         # TODO
 
+    def draw_erase(self, x, y, width, height, frame=None):
+        """Erase part of the sprite.
+
+        Arguments:
+
+        - ``x`` -- The horizontal location relative to the sprite of the
+          area to erase.
+        - ``y`` -- The vertical location relative to the sprite of the
+          area to erase.
+        - ``width`` -- The width of the area to erase.
+        - ``height`` -- The height of the area to erase.
+        - ``frame`` -- The frame of the sprite to erase from, where
+          ``0`` is the first frame; set to :const:`None` to erase from
+          all frames.
+
+        """
+        # TODO
+
     def draw_clear(self, frame=None):
         """Erase everything from the sprite.
 
@@ -415,6 +430,41 @@ class Sprite(object):
         - ``frame`` -- The frame of the sprite to clear, where ``0`` is
           the first frame; set to :const:`None` to clear all frames.
 
+        """
+        self.draw_erase(0, 0, self.width, self.height, frame)
+
+    def draw_lock(self):
+        """Lock the sprite for continuous drawing.
+
+        Use this method to "lock" the sprite for being drawn on several
+        times in a row.  What exactly this does depends on the
+        implementation and it may even do nothing at all, but calling
+        this method before doing several draw actions on the sprite in a
+        row gives the SGE a chance to make the drawing more efficient.
+
+        After you are done with continuous drawing, call
+        :meth:`sge.Sprite.draw_unlock` to let the SGE know that you are
+        done drawing.
+
+        .. warning::
+
+           Do not cause a sprite to be used while it's locked.  For
+           example, don't leave it locked for the duration of a frame,
+           and don't draw it or project it on anything.  The effect of
+           using a locked sprite could be as minor as graphical errors
+           and as severe as crashing the program, depending on the SGE
+           implementation.  Always call :meth:`sge.Sprite.draw_unlock`
+           immediately after you're done drawing for a while.
+
+        """
+        # TODO
+
+    def draw_unlock(self):
+        """Unlock the sprite.
+
+        Use this method to "unlock" the sprite after it has been
+        "locked" for continuous drawing by :meth:`sge.Sprite.draw_lock`.
+
         """
         # TODO
 
