@@ -14,9 +14,9 @@
 # above as well as the notices contained in other source files with your
 # own copyright notice.  Recommended free  licenses are  the GNU General
 # Public License, GNU Lesser General Public License, Expat License, or
-# Apache License 2.0.
+# Apache License.
 
-__all__ = ['StellarClass', 'Mouse']
+import sge
 
 
 class StellarClass(object):
@@ -68,8 +68,8 @@ class StellarClass(object):
           addition, collision events and destroy events still occur even
           if the object is inactive.  If you wish for the object to not
           be visible, set :attr:`visible` to :const:`False`.  If you
-          wish for the object to not be involved in collisions, set
-          :attr:`detects_collisions` to :const:`False`.
+          wish for the object to not perform collision events, set
+          :attr:`checks_collisions` to :const:`False`.
 
        .. note::
 
@@ -82,11 +82,26 @@ class StellarClass(object):
           would otherwise occur, or to prevent the object from moving
           through walls).
 
-    .. attribute:: detects_collisions
+    .. attribute:: checks_collisions
 
-       Whether or not the object should be involved in collision
-       detection.  Setting this to :const:`False` can improve
-       performance if the object doesn't need to detect collisions.
+       Whether or not the object should check for collisions
+       automatically and cause collision events.  If an object is not
+       using collision events, setting this to :const:`False` will give
+       a boost in performance.
+
+       .. note::
+
+          This will not prevent automatic collision detection by other
+          objects from detecting this object, and it will also not
+          prevent this object's collision events from being executed.
+          If you wish to disable collision detection entirely, set
+          :attr:`tangible` to :const:`False`.
+
+    .. attribute:: tangible
+
+       Whether or not collisions involving the object can be detected.
+       Setting this to :const:`False` can improve performance if the
+       object doesn't need to be involved in collisions.
 
        Depending on the game, a useful strategy to boost performance can
        be to exclude an object from collision detection while it is
@@ -94,6 +109,13 @@ class StellarClass(object):
        :attr:`active` to :const:`False` as well so that the object
        doesn't move in undesireable ways (e.g. through walls).
 
+       .. note::
+
+          If this is :const:`False`, :attr:`checks_collisions` is
+          implied to be :const:`False` as well regardless of its actual
+          value.  This is because checking for collisions which can't be
+          detected is meaningless.
+
     .. attribute:: bbox_x
 
        The horizontal location of the bounding box relative to the
@@ -275,8 +297,8 @@ class StellarClass(object):
     """
 
     def __init__(self, x, y, z=0, ID=None, sprite=None, visible=True,
-                 active=True, detects_collisions=True, bbox_x=None,
-                 bbox_y=None, bbox_width=None, bbox_height=None,
+                 active=True, checks_collisions=True, tangible=True,
+                 bbox_x=None, bbox_y=None, bbox_width=None, bbox_height=None,
                  regulate_origin=False, collision_ellipse=False,
                  collision_precise=False, xvelocity=0, yvelocity=0,
                  image_index=0, image_origin_x=None, image_origin_y=None,
@@ -326,29 +348,22 @@ class StellarClass(object):
     def set_alarm(self, alarm_id, value):
         """Set an alarm.
 
-        Arguments:
-
-        - ``alarm_id`` -- The unique identifier of the alarm to set.
-          Any value can be used as a unique identifier for an alarm.
-        - ``value`` -- The value to set the alarm to.  Set to
-          :const:`None` to disable the alarm.
-
         After this method is called, ``value`` will reduce by 1 each
         frame (adjusted for delta timing if it is enabled) until it
         reaches 0, at which point :meth:`sge.StellarClass.event_alarm`
         will be executed with ``alarm_id``.
 
+        See the documentation for :meth:`sge.Game.set_alarm` for more
+        information.
+
         """
         # TODO
 
     def get_alarm(self, alarm_id):
         """Return the value of an alarm.
 
-        Arguments:
-
-        - ``alarm_id`` -- The unique identifier of the alarm to check.
-
-        If the alarm has not been set, :const:`None` will be returned.
+        See the documentation for :meth:`sge.Game.get_alarm` for more
+        information.
 
         """
         # TODO
@@ -418,12 +433,8 @@ class StellarClass(object):
     def event_alarm(self, alarm_id):
         """Alarm event.
 
-        Called when the value of an alarm reaches 0.
-
-        Arguments:
-
-        - ``alarm_id`` -- The unique identifier of the alarm which was
-          set off.
+        See the documentation for :meth:`sge.Game.event_alarm` for more
+        information.
 
         """
         pass
@@ -439,8 +450,8 @@ class StellarClass(object):
     def event_key_press(self, key, char):
         """Key press event.
 
-        See the documentation for :meth:`sge.Game.event_key_press` for
-        more information.
+        See the documentation for :class:`sge.input.KeyPress` for more
+        information.
 
         """
         pass
@@ -448,8 +459,8 @@ class StellarClass(object):
     def event_key_release(self, key):
         """Key release event.
 
-        See the documentation for :meth:`sge.Game.event_key_release` for
-        more information.
+        See the documentation for :class:`sge.input.KeyRelease` for more
+        information.
 
         """
         pass
@@ -457,8 +468,8 @@ class StellarClass(object):
     def event_mouse_move(self, x, y):
         """Mouse move event.
 
-        See the documentation for :meth:`sge.Game.event_mouse_move` for
-        more information.
+        See the documentation for :class:`sge.input.MouseMove` for more
+        information.
 
         """
         pass
@@ -466,8 +477,8 @@ class StellarClass(object):
     def event_mouse_button_press(self, button):
         """Mouse button press event.
 
-        See the documentation for
-        :meth:`sge.Game.event_mouse_button_press` for more information.
+        See the documentation for :class:`sge.input.MouseButtonPress`
+        for more information.
 
         """
         pass
@@ -475,57 +486,53 @@ class StellarClass(object):
     def event_mouse_button_release(self, button):
         """Mouse button release event.
 
-        See the documentation for
-        :meth:`sge.Game.event_mouse_button_release` for more
-        information.
+        See the documentation for :class:`sge.input.MouseButtonRelease`
+        for more information.
 
         """
         pass
 
-    def event_joystick_axis_move(self, name, ID, axis, value):
+    def event_joystick_axis_move(self, js_name, js_id, axis, value):
         """Joystick axis move event.
 
-        See the documentation for
-        :meth:`sge.Game.event_joystick_axis_move` for more information.
+        See the documentation for :class:`sge.input.JoystickAxisMove`
+        for more information.
 
         """
         pass
 
-    def event_joystick_hat_move(self, name, ID, hat, x, y):
-        """Joystick HAT move event.
+    def event_joystick_hat_move(self, js_name, js_id, hat, x, y):
+        """Joystick hat move event.
 
-        See the documentation for
-        :meth:`sge.Game.event_joystick_hat_move` for more information.
+        See the documentation for :class:`sge.input.JoystickHatMove` for
+        more information.
 
         """
         pass
 
-    def event_joystick_trackball_move(self, name, ID, ball, x, y):
+    def event_joystick_trackball_move(self, js_name, js_id, ball, x, y):
         """Joystick trackball move event.
 
         See the documentation for
-        :meth:`sge.Game.event_joystick_trackball_move` for more
-        information.
+        :class:`sge.input.JoystickTrackballMove` for more information.
 
         """
         pass
 
-    def event_joystick_button_press(self, name, ID, button):
+    def event_joystick_button_press(self, js_name, js_id, button):
         """Joystick button press event.
 
-        See the documentation for
-        :meth:`sge.Game.event_joystick_button_press` for more
-        information.
+        See the documentation for :class:`sge.input.JoystickButtonPress`
+        for more information.
 
         """
         pass
 
-    def event_joystick_button_release(self, name, ID, button):
+    def event_joystick_button_release(self, js_name, js_id, button):
         """Joystick button release event.
 
         See the documentation for
-        :meth:`sge.Game.event_joystick_button_release` for more
-        information.
+        :class:`sge.input.JoystickButtonRelease` for more information.
 
         """
         pass
@@ -634,7 +641,7 @@ class StellarClass(object):
 
         See the documentation for :meth:`sge.StellarClass.event_step`
         for more information.  The object is considered to be inactive
-        when :attr:`active` is :attr:`False`.
+        when :attr:`active` is :const:`False`.
 
         """
         pass
@@ -645,7 +652,7 @@ class StellarClass(object):
         See the documentation for
         :meth:`sge.StellarClass.event_end_step` for more information.
         The object is considered to be inactive when :attr:`active` is
-        :attr:`False`.
+        :const:`False`.
 
         """
         pass
@@ -653,9 +660,11 @@ class StellarClass(object):
     def event_inactive_key_press(self, key, char):
         """Key press event when this object is inactive.
 
-        See the documentation for :meth:`sge.Game.event_key_press` for
-        more information.  The object is considered to be inactive when
-        :attr:`active` is :const:`False`.
+        The object is considered to be inactive when :attr:`active` is
+        :const:`False`.
+
+        See the documentation for :class:`sge.input.KeyPress` for more
+        information.
 
         """
         pass
@@ -663,9 +672,11 @@ class StellarClass(object):
     def event_inactive_key_release(self, key):
         """Key release event when this object is inactive.
 
-        See the documentation for :meth:`sge.Game.event_key_release` for
-        more information.  The object is considered to be inactive when
-        :attr:`active` is :attr:`False`.
+        The object is considered to be inactive when :attr:`active` is
+        :const:`False`.
+
+        See the documentation for :class:`sge.input.KeyRelease` for more
+        information.
 
         """
         pass
@@ -673,9 +684,11 @@ class StellarClass(object):
     def event_inactive_mouse_move(self, x, y):
         """Mouse move event when this object is inactive.
 
-        See the documentation for :meth:`sge.Game.event_mouse_move` for
-        more information.  The object is considered to be inactive when
-        :attr:`active` is :attr:`False`.
+        The object is considered to be inactive when :attr:`active` is
+        :const:`False`.
+
+        See the documentation for :class:`sge.input.MouseMove` for more
+        information.
 
         """
         pass
@@ -683,10 +696,11 @@ class StellarClass(object):
     def event_inactive_mouse_button_press(self, button):
         """Mouse button press event when this object is inactive.
 
-        See the documentation for
-        :meth:`sge.Game.event_mouse_button_press` for more information.
         The object is considered to be inactive when :attr:`active` is
-        :attr:`False`.
+        :const:`False`.
+
+        See the documentation for :class:`sge.input.MouseButtonPress`
+        for more information.
 
         """
         pass
@@ -694,65 +708,71 @@ class StellarClass(object):
     def event_inactive_mouse_button_release(self, button):
         """Mouse button release event when this object is inactive.
 
-        See the documentation for
-        :meth:`sge.Game.event_mouse_button_release` for more
-        information.  The object is considered to be inactive when
-        :attr:`active` is :attr:`False`.
+        The object is considered to be inactive when :attr:`active` is
+        :const:`False`.
+
+        See the documentation for :class:`sge.input.MouseButtonRelease`
+        for more information.
 
         """
         pass
 
-    def event_inactive_joystick_axis_move(self, name, ID, axis, value):
+    def event_inactive_joystick_axis_move(self, js_name, js_id, axis, value):
         """Joystick axis move event when this object is inactive.
 
-        See the documentation for
-        :meth:`sge.Game.event_joystick_axis_move` for more information.
         The object is considered to be inactive when :attr:`active` is
-        :attr:`False`.
+        :const:`False`.
+
+        See the documentation for :class:`sge.input.JoystickAxisMove`
+        for more information.
 
         """
         pass
 
-    def event_inactive_joystick_hat_move(self, name, ID, hat, x, y):
-        """Joystick HAT move event when this object is inactive.
+    def event_inactive_joystick_hat_move(self, js_name, js_id, hat, x, y):
+        """Joystick hat move event when this object is inactive.
 
-        See the documentation for
-        :meth:`sge.Game.event_joystick_hat_move` for more information.
         The object is considered to be inactive when :attr:`active` is
-        :attr:`False`.
+        :const:`False`.
+
+        See the documentation for :class:`sge.input.JoystickHatMove` for
+        more information.
 
         """
         pass
 
-    def event_inactive_joystick_trackball_move(self, name, ID, ball, x, y):
+    def event_inactive_joystick_trackball_move(self, js_name, js_id, ball, x, y):
         """Joystick trackball move event when this object is inactive.
 
+        The object is considered to be inactive when :attr:`active` is
+        :const:`False`.
+
         See the documentation for
-        :meth:`sge.Game.event_joystick_trackball_move` for more
-        information.  The object is considered to be inactive when
-        :attr:`active` is :attr:`False`.
+        :class:`sge.input.JoystickTrackballMove` for more information.
 
         """
         pass
 
-    def event_inactive_joystick_button_press(self, name, ID, button):
+    def event_inactive_joystick_button_press(self, js_name, js_id, button):
         """Joystick button press event when this object is inactive.
 
-        See the documentation for
-        :meth:`sge.Game.event_joystick_button_press` for more
-        information.  The object is considered to be inactive when
-        :attr:`active` is :attr:`False`.
+        The object is considered to be inactive when :attr:`active` is
+        :const:`False`.
+
+        See the documentation for :class:`sge.input.JoystickButtonPress`
+        for more information.
 
         """
         pass
 
-    def event_inactive_joystick_button_release(self, name, ID, button):
+    def event_inactive_joystick_button_release(self, js_name, js_id, button):
         """Joystick button release event when this object is inactive.
 
+        The object is considered to be inactive when :attr:`active` is
+        :const:`False`.
+
         See the documentation for
-        :meth:`sge.Game.event_joystick_button_release` for more
-        information.  The object is considered to be inactive when
-        :attr:`active` is :attr:`False`.
+        :class:`sge.input.JoystickButtonRelease` for more information.
 
         """
         pass
@@ -760,8 +780,8 @@ class StellarClass(object):
     def event_paused_key_press(self, key, char):
         """Key press event when paused.
 
-        See the documentation for :meth:`sge.Game.event_key_press` for
-        more information.
+        See the documentation for :class:`sge.input.KeyPress` for more
+        information.
 
         """
         pass
@@ -769,8 +789,8 @@ class StellarClass(object):
     def event_paused_key_release(self, key):
         """Key release event when paused.
 
-        See the documentation for :meth:`sge.Game.event_key_release` for
-        more information.
+        See the documentation for :class:`sge.input.KeyRelease` for more
+        information.
 
         """
         pass
@@ -778,8 +798,8 @@ class StellarClass(object):
     def event_paused_mouse_move(self, x, y):
         """Mouse move event when paused.
 
-        See the documentation for :meth:`sge.Game.event_mouse_move` for
-        more information.
+        See the documentation for :class:`sge.input.MouseMove` for more
+        information.
 
         """
         pass
@@ -787,8 +807,8 @@ class StellarClass(object):
     def event_paused_mouse_button_press(self, button):
         """Mouse button press event when paused.
 
-        See the documentation for
-        :meth:`sge.Game.event_mouse_button_press` for more information.
+        See the documentation for :class:`sge.input.MouseButtonPress`
+        for more information.
 
         """
         pass
@@ -796,57 +816,53 @@ class StellarClass(object):
     def event_paused_mouse_button_release(self, button):
         """Mouse button release event when paused.
 
-        See the documentation for
-        :meth:`sge.Game.event_mouse_button_release` for more
-        information.
+        See the documentation for :class:`sge.input.MouseButtonRelease`
+        for more information.
 
         """
         pass
 
-    def event_paused_joystick_axis_move(self, name, ID, axis, value):
+    def event_paused_joystick_axis_move(self, js_name, js_id, axis, value):
         """Joystick axis move event when paused.
 
-        See the documentation for
-        :meth:`sge.Game.event_joystick_axis_move` for more information.
+        See the documentation for :class:`sge.input.JoystickAxisMove`
+        for more information.
 
         """
         pass
 
-    def event_paused_joystick_hat_move(self, name, ID, hat, x, y):
-        """Joystick HAT move event when paused.
+    def event_paused_joystick_hat_move(self, js_name, js_id, hat, x, y):
+        """Joystick hat move event when paused.
 
-        See the documentation for
-        :meth:`sge.Game.event_joystick_hat_move` for more information.
+        See the documentation for :class:`sge.input.JoystickHatMove` for
+        more information.
 
         """
         pass
 
-    def event_paused_joystick_trackball_move(self, name, ID, ball, x, y):
+    def event_paused_joystick_trackball_move(self, js_name, js_id, ball, x, y):
         """Joystick trackball move event when paused.
 
         See the documentation for
-        :meth:`sge.Game.event_joystick_trackball_move` for more
-        information.
+        :class:`sge.input.JoystickTrackballMove` for more information.
 
         """
         pass
 
-    def event_paused_joystick_button_press(self, name, ID, button):
+    def event_paused_joystick_button_press(self, js_name, js_id, button):
         """Joystick button press event when paused.
 
-        See the documentation for
-        :meth:`sge.Game.event_joystick_button_press` for more
-        information.
+        See the documentation for :class:`sge.input.JoystickButtonPress`
+        for more information.
 
         """
         pass
 
-    def event_paused_joystick_button_release(self, name, ID, button):
+    def event_paused_joystick_button_release(self, js_name, js_id, button):
         """Joystick button release event when paused.
 
         See the documentation for
-        :meth:`sge.Game.event_joystick_button_release` for more
-        information.
+        :class:`sge.input.JoystickButtonRelease` for more information.
 
         """
         pass
