@@ -14,7 +14,7 @@
 # above as well as the notices contained in other source files with your
 # own copyright notice.  Recommended free  licenses are the GNU General
 # Public License, GNU Lesser General Public License, Expat License, or
-# Apache License 2.0.
+# Apache License.
 
 """
 The Stellar Game Engine (abbreviated "SGE", pronounced as "Sage") is a
@@ -27,11 +27,11 @@ Official implementations of the SGE are `free/libre software
 <http://gnu.org/philosophy/free-sw.html>`_, and the SGE documentation is
 free/libre as well.
 
-Even if it isn't required of you, we encourage you to release your
-games' code under a free/libre software license, such as the GNU General
-Public License, the Expat License, or the Apache License.  Doing so is
-easy, does not negatively affect you, and is highly appreciated as a
-contribution to free/libre software.
+Even if it isn't required, you are encouraged to release your games'
+code under a free/libre software license, such as the GNU General Public
+License, the Expat License, or the Apache License.  Doing so is easy,
+does not negatively affect you, and is highly appreciated as a
+contribution to a free society.
 
 SGE Concepts
 ============
@@ -62,27 +62,12 @@ event method (with a name that begins with ``event_``) is called. To
 define actions triggered by events, simply override the appropriate
 event method.
 
-The Mouse
----------
-
-The mouse is handled somewhat unusually by the SGE.  Rather than having
-functions or variables report the mouse position relative to the screen,
-the mouse position within the room, calculated based on its position on
-the screen by the SGE, is recorded in a special
-:class:`sge.StellarClass` object which represents the mouse.  This mouse
-object can be found as :attr:`sge.game.mouse`, and it has the special
-object ID, ``"mouse"``.
-
-The mouse object differs from most :class:`sge.StellarClass` objects in
-a few ways.  Its speed variables cannot be manually set, and they always
-report numbers which correspond to the average motion of the mouse
-during the last quarter of a second.  Setting
-:attr:`sge.game.mouse.visible` toggles whether or not the mouse cursor
-itself is visible, and setting :attr:`sge.game.mouse.sprite` sets the
-mouse cursor to the sprite assigned.
-
-In all other ways, the mouse object is exactly the same as all other
-:class:`sge.StellarClass` objects.
+At a lower level, it is possible to read "input events" from
+:attr:`sge.game.input_events` and handle them manually.  See the
+documentation for :mod:`sge.input` for more information.  This is not
+recommended, however, unless you are running your own loop for some
+reason (in which case it is necessary to do this in order to get input
+from the user).
 
 Colors
 ------
@@ -178,6 +163,45 @@ allowed to change this decision, but only while the objects in question
 are not overlapping, since changing the decision while the two objects
 are overlapping would cause an undesirable flicker effect.
 
+The Game Loop
+-------------
+
+There can occasionally be times where you want to run your own loop,
+independent of the SGE's main loop.  This is not recommended in general,
+but if you must (to freeze the game, for example), you should know the
+general game loop structure::
+
+    while True:
+        # Input events
+        sge.game.pump_input()
+        while sge.game.input_events:
+            event = sge.game.input_events.pop(0)
+
+            # Handle event
+
+        # Regulate speed
+        time_passed = sge.game.regulate_speed()
+
+        # Logic (e.g. collision detection and step events)
+
+        # Refresh
+        sge.game.refresh()
+
+:meth:`sge.Game.pump_input` should be called every frame regardless of
+whether or not user input is needed.  Failing to call it will cause the
+queue to build up, but more importantly, the OS may decide that the
+program has locked up if it doesn't get a response for a long time.
+
+:meth:`sge.Game.regulate_speed` limits the frame rate of the game and
+tells you how much time has passed since the last frame.  It is not
+technically necessary, but using it is highly recommended; otherwise,
+the CPU will be working harder than it needs to and if things are
+moving, their speed will be irregular.
+
+:meth:`sge.Game.refresh` is necessary for any changes to the screen to
+be seen by the user.  This includes new objects, removed objects, new
+projections, discontinued projections, etc.
+
 Global Variables and Constants
 ==============================
 
@@ -339,13 +363,103 @@ Dependencies
 
 """
 
-__version__ = "0.9.2"
+__version__ = "0.10.0"
 
+import sys
 import os
 
 # Import implementation-specific libraries like Pygame here
 
-from sge.constants import *
+# Constants
+PROGRAM_DIR = os.path.dirname(sys.argv[0])
+IMPLEMENTATION = "SGE Specification"
+
+ALIGN_LEFT = 2
+ALIGN_CENTER = 3
+ALIGN_RIGHT = 1
+ALIGN_TOP = 8
+ALIGN_MIDDLE = 12
+ALIGN_BOTTOM = 4
+
+BLEND_NORMAL = 0
+BLEND_RGB = 1
+BLEND_ALPHA = 2
+BLEND_ADD = 4
+BLEND_SUBTRACT = 8
+BLEND_MULTIPLY = 12
+BLEND_SCREEN = 16
+BLEND_MINIMUM = 20
+BLEND_MAXIMUM = 24
+
+BLEND_RGBA_ADD = BLEND_RGB | BLEND_ALPHA | BLEND_ADD
+BLEND_RGBA_SUBTRACT = BLEND_RGB | BLEND_ALPHA | BLEND_SUBTRACT
+BLEND_RGBA_MULTIPLY = BLEND_RGB | BLEND_ALPHA | BLEND_MULTIPLY
+BLEND_RGBA_SCREEN = BLEND_RGB | BLEND_ALPHA | BLEND_SCREEN
+BLEND_RGBA_MINIMUM = BLEND_RGB | BLEND_ALPHA | BLEND_MINIMUM
+BLEND_RGBA_MAXIMUM = BLEND_RGB | BLEND_ALPHA | BLEND_MAXIMUM
+
+BLEND_RGB_ADD = BLEND_RGB | BLEND_ADD
+BLEND_RGB_SUBTRACT = BLEND_RGB | BLEND_SUBTRACT
+BLEND_RGB_MULTIPLY = BLEND_RGB | BLEND_MULTIPLY
+BLEND_RGB_SCREEN = BLEND_RGB | BLEND_SCREEN
+BLEND_RGB_MINIMUM = BLEND_RGB | BLEND_MINIMUM
+BLEND_RGB_MAXIMUM = BLEND_RGB | BLEND_MAXIMUM
+
+COLORS = {'white': '#ffffff', 'silver': '#c0c0c0', 'gray': '#808080',
+          'black': '#000000', 'red': '#ff0000', 'maroon': '#800000',
+          'yellow': '#ffff00', 'olive': '#808000', 'lime': '#00ff00',
+          'green': '#008000', 'aqua': '#00ffff', 'teal': '#008080',
+          'blue': '#0000ff', 'navy': '#000080', 'fuchsia': '#ff00ff',
+          'purple': '#800080'}
+COLOR_NAMES = {}
+for pair in COLORS.items():
+    COLOR_NAMES[pair[1]] = pair[0]
+
+KEYS = {"0": None, "1": None, "2": None, "3": None, "4": None, "5": None,
+        "6": None, "7": None, "8": None, "9": None, "a": None, "b": None,
+        "c": None, "d": None, "e": None, "f": None, "g": None, "h": None,
+        "i": None, "j": None, "k": None, "l": None, "m": None, "n": None,
+        "o": None, "p": None, "q": None, "r": None, "s": None, "t": None,
+        "u": None, "v": None, "w": None, "x": None, "y": None, "z": None,
+        "alt_left": None, "alt_right": None, "ampersand": None,
+        "apostrophe": None, "asterisk": None, "at": None, "backslash": None,
+        "backspace": None, "backtick": None, "bracket_left": None,
+        "bracket_right": None, "break": None, "caps_lock": None, "caret": None,
+        "clear": None, "colon": None, "comma": None, "ctrl_left": None,
+        "ctrl_right": None, "delete": None, "dollar": None, "down": None,
+        "end": None, "enter": None, "equals": None, "escape": None,
+        "euro": None, "exclamation": None, "f1": None, "f2": None, "f3": None,
+        "f4": None, "f5": None, "f6": None, "f7": None, "f8": None, "f9": None,
+        "f10": None, "f11": None, "f12": None, "greater_than": None,
+        "hash": None, "help": None, "home": None, "hyphen": None,
+        "insert": None, "kp_0": None, "kp_1": None, "kp_2": None, "kp_3": None,
+        "kp_4": None, "kp_5": None, "kp_6": None, "kp_7": None, "kp_8": None,
+        "kp_9": None, "kp_divide": None, "kp_enter": None, "kp_equals": None,
+        "kp_minus": None, "kp_multiply": None, "kp_plus": None,
+        "kp_point": None, "left": None, "less_than": None, "menu": None,
+        "meta_left": None, "meta_right": None, "mode": None, "num_lock": None,
+        "pagedown": None, "pageup": None, "parenthesis_left": None,
+        "parenthesis_right": None, "pause": None, "period": None, "plus": None,
+        "power": None, "print_screen": None, "question": None, "quote": None,
+        "right": None, "scroll_lock": None, "semicolon": None,
+        "shift_left": None, "shift_right": None, "slash": None, "space": None,
+        "super_left": None, "super_right": None, "sysrq": None, "tab": None,
+        "underscore": None, "up":None}
+KEY_NAMES = {}
+for pair in KEYS.items():
+    KEY_NAMES[pair[1]] = pair[0]
+
+MODS = {"alt": None, "alt_left": None, "alt_right": None, "caps_lock": None,
+        "ctrl": None, "ctrl_left": None, "ctrl_right": None, "meta": None,
+        "meta_left": None, "meta_right": None, "mode": None, "num_lock": None,
+        "shift": None, "shift_left": None, "shift_right": None}
+
+MOUSE_BUTTONS = {"left": 0, "right": 1, "middle": 2, "wheel_up": 3,
+                 "wheel_down": 4, "wheel_left": 5, "wheel_right": 6}
+MOUSE_BUTTON_NAMES = {}
+for pair in MOUSE_BUTTONS.items():
+    MOUSE_BUTTON_NAMES[pair[1]] = pair[0]
+
 from sge.Game import Game
 from sge.Sprite import Sprite
 from sge.BackgroundLayer import BackgroundLayer
@@ -356,13 +470,12 @@ from sge.Music import Music
 from sge.StellarClass import StellarClass, Mouse
 from sge.Room import Room
 from sge.View import View
-from sge.functions import *
-from sge import collision
+from sge import collision, input, joystick, keyboard, mouse
 
 
 __all__ = [
     # Modules
-    "collision",
+    "collision", "input", "joystick", "keyboard", "mouse",
 
     # Constants
     'IMPLEMENTATION', 'ALIGN_LEFT', 'ALIGN_CENTER', 'ALIGN_RIGHT', 'ALIGN_TOP',
@@ -377,11 +490,7 @@ __all__ = [
     'Music', 'StellarClass', 'Room', 'View',
 
     # Functions
-    'show_message', 'get_text_entry', 'get_key_pressed',
-    'get_mouse_button_pressed', 'get_joystick_axis', 'get_joystick_hat',
-    'get_joystick_button_pressed', 'get_joysticks', 'get_joystick_name',
-    'get_joystick_id', 'get_joystick_axes', 'get_joystick_hats',
-    'get_joystick_trackballs', 'get_joystick_buttons'
+    'show_message', 'get_text_entry'
     ]
 
 # Global variables
